@@ -23,7 +23,7 @@
 #' below.
 #' @param parent (character) A parent name (i.e., the parent of the target search
 #' taxon). Optional. See `Filtering` below.
-#' @param rank (character) A taxonomic rank name. See [rank_ref()] for possible
+#' @param rank (character) A taxonomic rank name. See [rank_ref] for possible
 #' options. Though note that some data sources use atypical ranks, so inspect the
 #' data itself for options. Optional. See `Filtering` below.
 #' @param check logical; Check if ID matches any existing on the DB, only used in
@@ -297,18 +297,18 @@ as.boldid.boldid <- function(x, check=TRUE) x
 #' @export
 #' @rdname get_boldid
 as.boldid.character <- function(x, check=TRUE) {
-  if (length(x) == 1) 
-    make_boldid(x, check) 
-  else 
+  if (length(x) == 1)
+    make_boldid(x, check)
+  else
     collapse(x, make_boldid, "boldid", check=check)
 }
 
 #' @export
 #' @rdname get_boldid
 as.boldid.list <- function(x, check=TRUE) {
-  if (length(x) == 1) 
-    make_boldid(x, check) 
-  else 
+  if (length(x) == 1)
+    make_boldid(x, check)
+  else
     collapse(x, make_boldid, "boldid", check=check)
 }
 
@@ -343,6 +343,10 @@ make_boldid <- function(x, check=TRUE) {
 }
 
 check_boldid <- function(x){
+
+  if(!requireNamespace("bold", quietly = TRUE))
+      stop("package 'bold' is reauireed but not available")
+
   tryid <- bold_tax_id(x)
   !identical("noresults", names(tryid)[2])
 }
@@ -360,7 +364,7 @@ get_boldid_ <- function(sci, messages = TRUE, fuzzy = FALSE,
 
 get_boldid_help <- function(sci, messages, fuzzy, dataTypes,
   includeTree, rows, ...){
-  
+
   mssg(messages, "\nRetrieving data for taxon '", sci, "'\n")
   df <- bold_search(name = sci, fuzzy = fuzzy, dataTypes = dataTypes,
     includeTree = includeTree)
