@@ -3,7 +3,10 @@
 #' @export
 #' @param tsn One or more TSN's (taxonomic serial number)
 #' @param what One of bytsn, values, or originvalues
-#' @param ... Further arguments passed on to \code{\link{getjurisdictionaloriginfromtsn}}
+#' @param ... Further arguments passed on to
+#' [ritis::jurisdictional_origin()],
+#' [ritis::jurisdiction_values()], or
+#' [ritis::jurisdiction_origin_values()]
 #' @examples \dontrun{
 #' # Get values
 #' itis_native(what="values")
@@ -17,15 +20,16 @@
 #' }
 
 itis_native <- function(tsn=NULL, what="bytsn", ...) {
-  switch(what,
-         bytsn = {
-           temp <- lapply(tsn, function(x) getjurisdictionaloriginfromtsn(x, ...))
-           if (length(tsn) == 1) {
-             temp[[1]]
-           } else {
-             setNames(temp, tsn)
-           }
-         },
-         values = getjurisdictionvalues(...),
-         originvalues = getjurisdictionoriginvalues(...))
+  switch(
+    what,
+    bytsn = {
+      temp <- lapply(tsn, function(x) ritis::jurisdictional_origin(x, ...))
+      if (length(tsn) == 1) {
+        temp[[1]]
+      } else {
+        setNames(temp, tsn)
+      }
+    },
+    values = ritis::jurisdiction_values(...),
+    originvalues = ritis::jurisdiction_origin_values(...))
 }
